/** Represents statuses of transactions. */
declare enum TransactionStatus {
    /**
     * The transaction failed because the provided paths did not have enough liquidity to send anything at all.
     * This could mean that the source and destination accounts are not linked by trust lines.
     * The transaction cost was destroyed.
     */
    ClaimedCostOnly_PathDry = 0,
    /**
     * The transaction failed because the provided paths did not have enough liquidity to send the full amount.
     * The transaction cost was destroyed.
     */
    ClaimedCostOnly_PathPartial = 1,
    /** The transaction did not achieve its intended purpose, but the transaction cost was destroyed. */
    ClaimedCostOnly = 2,
    /** The transaction is not included in a finalized ledger, and is not valid, due to improper syntax, conflicting options, a bad signature, or something else. */
    MalformedTransaction = 3,
    /** The transaction was included in a finalized ledger and failed. */
    Failed = 4,
    /** The transaction is not included in a finalized ledger. */
    Pending = 5,
    /** The transaction was included in a finalized ledger and succeeded. */
    Succeeded = 6,
    /** The transaction's last ledger sequence has been surpassed; the transaction will never be included in a validated ledger. */
    LastLedgerSequenceExpired = 7,
    /** The transaction status is unknown. */
    Unknown = 8
}
export default TransactionStatus;
